@@ -3,7 +3,7 @@ import sys
 import time
 import threading
 
-from pyjoystick.utils import PYJOYSTICK_DIR, deadband, change_path, rescale
+from pyjoystick.utils import PYJOYSTICK_DIR, change_path, rescale
 
 with change_path(PYJOYSTICK_DIR):
     # os.environ.setdefault('SDL_VIDEODRIVER', 'dummy')
@@ -13,7 +13,7 @@ from pyjoystick.stash import Stash
 from pyjoystick.interface import Key, Joystick as BaseJoystick
 
 
-__all__ = ['Key', 'Joystick', 'run_event_loop',
+__all__ = ['Key', 'Joystick', 'run_event_loop', 'stop_event_wait',
            'get_init', 'init', 'quit', 'key_from_event',
            'refresh_joysticks']
 
@@ -73,7 +73,7 @@ class Joystick(BaseJoystick):
 
         return joy
 
-    def is_active(self):
+    def is_available(self):
         """Return if this joystick is still active and available."""
         try:
             return self.joystick.get_init()
@@ -169,11 +169,7 @@ def key_from_event(event, joystick=None):
     elif event.type == pygame.JOYBUTTONUP:
         return Key(Key.BUTTON, event.button, 0, joystick)
     elif event.type == pygame.JOYAXISMOTION:
-        value = event.value
-        db = getattr(joystick, 'deadband', 0)
-        if db:
-            value = deadband(value, db)
-        return Key(Key.AXIS, event.axis, value, joystick)
+        return Key(Key.AXIS, event.axis, event.value, joystick)
     elif event.type == pygame.JOYHATMOTION:
         value = HAT_CONVERTER.get(tuple(event.value), Key.HAT_CENTERED)
         return Key(Key.HAT, event.hat, value, joystick)
@@ -230,6 +226,14 @@ def get_events():
         return pygame.event.get()
 
 
+def stop_event_wait():
+    """Post an event to break out of the event loop wait."""
+    try:
+        pygame.event.post(pygame.event.Event(pygame.USEREVENT, {}))  # Break out of wait
+    except Exception:
+        pass
+
+
 def run_event_loop(add_joystick, remove_joystick, handle_key_event, alive=None, refresh_timeout=2, **kwargs):
     """Main function to run and handle events.
 
@@ -273,3 +277,7 @@ def run_event_loop(add_joystick, remove_joystick, handle_key_event, alive=None,
                 time.sleep(0.01)
         except:
             pass
+
+
+# Attach a way to stop waiting by posting an event
+run_event_loop.stop_event_wait = stop_event_wait
